import { ValidateMessage } from '@opensumi/ide-components';
import { IDisposable } from '@opensumi/ide-core-browser';
import { CancellationToken, Disposable } from '@opensumi/ide-core-common';
import { ICodeEditor, IEditorDocumentModelService } from '@opensumi/ide-editor/lib/browser';
import * as monaco from '@opensumi/ide-monaco';
import { ContentSearchOptions, ContentSearchResult, IContentSearchClientService, IUIState, ResultTotal, SEARCH_STATE, SendClientResult } from '../common';
import { SearchHistory } from './search-history';
import { SearchResultCollection } from './search-result-collection';
export interface SearchAllFromDocModelOptions {
    searchValue: string;
    searchOptions: ContentSearchOptions;
    documentModelManager: IEditorDocumentModelService;
    rootDirs: string[];
}
/**
 * 用于文件内容搜索
 */
export declare class ContentSearchClientService extends Disposable implements IContentSearchClientService {
    private readonly eventBus;
    private readonly searchPreferences;
    private readonly corePreferences;
    private readonly contentSearchServer;
    private readonly workspaceService;
    private readonly recentStorage;
    private readonly documentModelManager;
    private readonly commandService;
    private readonly browserStorageService;
    private readonly dialogService;
    private readonly messageService;
    private readonly workspaceEditService;
    private reporterService;
    private readonly preferenceService;
    private readonly workbenchEditorService;
    private readonly resourceService;
    private onDidChangeEmitter;
    private onDidTitleChangeEmitter;
    private onDidUIStateChangeEmitter;
    private onDidSearchStateChangeEmitter;
    protected eventBusDisposer: IDisposable;
    get onDidChange(): import("@opensumi/ide-core-browser").Event<void>;
    get onDidTitleChange(): import("@opensumi/ide-core-browser").Event<void>;
    get onDidUIStateChange(): import("@opensumi/ide-core-browser").Event<IUIState>;
    get onDidSearchStateChange(): import("@opensumi/ide-core-browser").Event<string>;
    UIState: IUIState;
    searchResults: Map<string, ContentSearchResult[]>;
    searchError: string;
    searchState: SEARCH_STATE;
    resultTotal: ResultTotal;
    isReplacing: boolean;
    isSearching: boolean;
    isShowValidateMessage: boolean;
    replaceValue: string;
    searchValue: string;
    includeValue: string;
    excludeValue: string;
    private _searchHistory;
    private _docModelSearchedList;
    private _currentSearchId;
    searchResultCollection: SearchResultCollection;
    private reporter;
    private searchCancelToken;
    private searchOnType;
    searchDebounce: () => void;
    constructor();
    private searchId;
    searchOnTyping(): void;
    search(insertUIState?: IUIState): Promise<void>;
    doSearch(value: string, state: IUIState, token: CancellationToken): Promise<void>;
    private EMPTY_SELECTION;
    private lastEditor?;
    private lastSelection?;
    setEditorSelections(editor: ICodeEditor, selections: monaco.Range): void;
    /**
     * 会在 tabbar 被选中时调用
     */
    applyEditorSelections(): void;
    /**
     * 会在 tabbar blur 和清除搜索结果时调用
     * @param clearEditor 是否清除上次选中的 editor（在重置搜索内容时调用）
     */
    clearEditorSelections(clearEditor?: boolean): void;
    /**
     * 监听正在编辑文件变化，并同步结果
     * @param searchOptions
     * @param rootDirs
     */
    watchDocModelContentChange(searchOptions: ContentSearchOptions, rootDirs: string[]): void;
    cleanSearchResults(): void;
    /**
     * 服务端发送搜索结果过来
     * @param sendClientResult
     */
    onSearchResult(sendClientResult: SendClientResult): void;
    private _onSearchResult;
    focus(): void;
    blur(): void;
    refreshIsEnable(): boolean;
    initSearchHistory(): Promise<void>;
    setBackRecentSearchWord(): any;
    setRecentSearchWord(): any;
    clean(): void;
    cleanIsEnable(): boolean;
    foldIsEnable(): boolean;
    onSearchInputChange: (text: string) => void;
    onReplaceInputChange: (text: string) => void;
    onSearchExcludeChange: (text: string) => void;
    onSearchIncludeChange: (text: string) => void;
    searchEditorSelection: () => void;
    private shouldSearch;
    updateUIState: (obj: Partial<typeof this.UIState>) => void;
    getPreferenceSearchExcludes(): string[];
    openPreference(): void;
    get searchHistory(): SearchHistory;
    get validateMessage(): ValidateMessage | undefined;
    replaceAll: () => void;
    private recoverUIState;
    private getExcludeWithSetting;
    private setDefaultIncludeValue;
    private mergeSameUriResult;
    private searchFromDocModel;
    private searchAllFromDocModel;
    fireTitleChange(): void;
    refresh(): void;
    dispose(): void;
}
//# sourceMappingURL=search.service.d.ts.map