"use strict";
var RangeHighlightDecorations_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchTreeService = exports.ReplaceDocumentModelContentProvider = exports.RangeHighlightDecorations = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const common_1 = require("@opensumi/ide-file-service/lib/common");
const monaco = tslib_1.__importStar(require("@opensumi/ide-monaco"));
const ide_workspace_1 = require("@opensumi/ide-workspace");
const ide_workspace_edit_1 = require("@opensumi/ide-workspace-edit");
const content_search_1 = require("../../common/content-search");
const replace_1 = require("../replace");
const search_contextkey_1 = require("../search-contextkey");
const tree_node_defined_1 = require("../tree/tree-node.defined");
let RangeHighlightDecorations = RangeHighlightDecorations_1 = class RangeHighlightDecorations {
    constructor() {
        this.preDeltaDecoration = null;
        this._model = null;
        this._modelRef = null;
        this._modelDisposables = new ide_core_common_1.DisposableStore();
    }
    removeHighlightRange() {
        if (this._model && this.preDeltaDecoration) {
            this._model.deltaDecorations(this.preDeltaDecoration, []);
        }
        this.preDeltaDecoration = null;
    }
    highlightRange(resource, range) {
        let model = null;
        if (ide_core_common_1.URI.isUri(resource)) {
            const modelRef = this.documentModelManager.getModelReference(resource, 'highlight-range');
            if (modelRef) {
                model = modelRef.instance.getMonacoModel();
                this._modelRef = modelRef;
            }
        }
        else {
            model = resource;
        }
        if (model) {
            this.doHighlightRange(model, range);
        }
    }
    doHighlightRange(model, range) {
        this.removeHighlightRange();
        this.preDeltaDecoration = model.deltaDecorations([], this.createEditorDecorations(range));
        this.setModel(model);
    }
    createEditorDecorations(range) {
        return [{ range, options: RangeHighlightDecorations_1.RANGE_HIGHLIGHT_DECORATION }];
    }
    setModel(model) {
        if (this._modelRef) {
            this._modelRef.dispose();
            this._modelRef = null;
        }
        if (this._model !== model) {
            this.clearModelListeners();
            this._model = model;
            this._modelDisposables.add(this._model.onWillDispose(() => {
                this.clearModelListeners();
                this.removeHighlightRange();
                this._model = null;
            }));
        }
    }
    clearModelListeners() {
        this._modelDisposables.clear();
    }
    dispose() {
        if (this._model) {
            this.removeHighlightRange();
            this._modelDisposables.dispose();
            this._model = null;
        }
    }
};
RangeHighlightDecorations.RANGE_HIGHLIGHT_DECORATION = {
    className: 'rangeHighlight',
    stickiness: monaco.editor.TrackedRangeStickiness.GrowsOnlyWhenTypingBefore,
    isWholeLine: true,
};
tslib_1.__decorate([
    (0, di_1.Autowired)(browser_1.IEditorDocumentModelService),
    tslib_1.__metadata("design:type", Object)
], RangeHighlightDecorations.prototype, "documentModelManager", void 0);
RangeHighlightDecorations = RangeHighlightDecorations_1 = tslib_1.__decorate([
    (0, di_1.Injectable)()
], RangeHighlightDecorations);
exports.RangeHighlightDecorations = RangeHighlightDecorations;
let ReplaceDocumentModelContentProvider = class ReplaceDocumentModelContentProvider {
    constructor() {
        this.contentMap = new Map();
        this.onDidChangeContentEvent = new ide_core_common_1.Emitter();
        this.onDidChangeContent = this.onDidChangeContentEvent.event;
    }
    handlesScheme(scheme) {
        return scheme === ide_core_common_1.Schemes.internal;
    }
    provideEditorDocumentModelContent(uri) {
        return this.contentMap.get(uri.toString()) || '';
    }
    isReadonly() {
        return true;
    }
    async updateContent(uri) {
        const sourceFileUri = uri.withScheme(JSON.parse(uri.query).scheme).withoutQuery().withoutFragment();
        const sourceDocModelRef = this.documentModelManager.getModelReference(sourceFileUri) ||
            (await this.documentModelManager.createModelReference(sourceFileUri));
        const sourceDocModel = sourceDocModelRef.instance;
        const value = sourceDocModel.getText();
        const replaceViewDocModelRef = this.documentModelManager.getModelReference(uri) || (await this.documentModelManager.createModelReference(uri));
        const replaceViewDocModel = replaceViewDocModelRef.instance;
        replaceViewDocModel.updateContent(value);
        let searchResults = this.searchBrowserService.searchResults.get(sourceFileUri.toString());
        if (!searchResults) {
            return '';
        }
        searchResults = searchResults.map((result) => Object.assign({}, result, {
            fileUri: uri.toString(),
        }));
        await (0, replace_1.replace)(this.documentModelManager, this.workspaceEditService, searchResults, this.searchBrowserService.replaceValue, this.searchBrowserService.searchValue, this.searchBrowserService.UIState.isUseRegexp);
        this.contentMap.set(uri.toString(), replaceViewDocModel.getText());
    }
    delete(uri) {
        this.contentMap.delete(uri.toString());
    }
    clear() {
        this.contentMap.clear();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(browser_1.IEditorDocumentModelService),
    tslib_1.__metadata("design:type", Object)
], ReplaceDocumentModelContentProvider.prototype, "documentModelManager", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(content_search_1.IContentSearchClientService),
    tslib_1.__metadata("design:type", Object)
], ReplaceDocumentModelContentProvider.prototype, "searchBrowserService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_workspace_edit_1.IWorkspaceEditService),
    tslib_1.__metadata("design:type", Object)
], ReplaceDocumentModelContentProvider.prototype, "workspaceEditService", void 0);
ReplaceDocumentModelContentProvider = tslib_1.__decorate([
    (0, di_1.Injectable)()
], ReplaceDocumentModelContentProvider);
exports.ReplaceDocumentModelContentProvider = ReplaceDocumentModelContentProvider;
let SearchTreeService = class SearchTreeService extends ide_core_common_1.Disposable {
    get viewReady() {
        return this.viewReadyDeferered.promise;
    }
    constructor() {
        super();
        this.viewReadyDeferered = new ide_core_common_1.Deferred();
        this.addDispose(this.rangeHighlightDecorations);
        this.addDispose(this.contentRegistry.registerEditorDocumentModelContentProvider(this.replaceDocumentModelContentProvider));
    }
    get replaceValue() {
        return this.searchBrowserService.replaceValue;
    }
    get resultTotal() {
        return this.searchBrowserService.resultTotal;
    }
    get contextKey() {
        return this.searchContextKey;
    }
    initContextKey(dom) {
        this.contextKey.initScopedContext(dom);
        this.viewReadyDeferered.resolve();
    }
    removeHighlightRange() {
        this.rangeHighlightDecorations.removeHighlightRange();
    }
    async resolveChildren(parent) {
        var _a;
        if (!parent) {
            const root = new tree_node_defined_1.SearchRoot(this);
            return [root];
        }
        else if (parent) {
            if (tree_node_defined_1.SearchRoot.isRoot(parent)) {
                const files = this.searchBrowserService.searchResults;
                if (!files) {
                    return [];
                }
                const childs = [];
                for (const filesArray of files) {
                    const uri = filesArray[0];
                    const resultList = filesArray[1];
                    const _uri = new ide_core_common_1.URI(uri);
                    const description = (_a = (await this.workspaceService.asRelativePath(_uri.parent))) === null || _a === void 0 ? void 0 : _a.path;
                    if (!resultList || resultList.length < 1) {
                        continue;
                    }
                    childs.push(new tree_node_defined_1.SearchFileNode(this, resultList, description, await this.getReadableTooltip(_uri), this.labelService.getIcon(_uri), _uri, parent));
                }
                return childs;
            }
            else {
                const contentResults = parent.contentResults;
                return contentResults.map((content) => {
                    const start = (content.renderStart || content.matchStart) - 1;
                    const end = start + content.matchLength;
                    const description = content.renderLineText || content.lineText;
                    return new tree_node_defined_1.SearchContentNode(this, content, description, { start, end }, parent.resource, parent);
                });
            }
        }
        return [];
    }
    async getCurrentUserHome() {
        if (!this.userhomePath) {
            try {
                const userhome = await this.fileServiceClient.getCurrentUserHome();
                if (userhome) {
                    this.userhomePath = new ide_core_common_1.URI(userhome.uri);
                }
            }
            catch (err) { }
        }
        return this.userhomePath;
    }
    async getReadableTooltip(path) {
        const pathStr = path.toString();
        const userhomePath = await this.getCurrentUserHome();
        if (!userhomePath) {
            return decodeURIComponent(path.withScheme('').toString());
        }
        if (userhomePath.isEqualOrParent(path)) {
            const userhomePathStr = userhomePath && userhomePath.toString();
            return decodeURIComponent(pathStr.replace(userhomePathStr, '~'));
        }
        return decodeURIComponent(path.withScheme('').toString());
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(content_search_1.IContentSearchClientService),
    tslib_1.__metadata("design:type", Object)
], SearchTreeService.prototype, "searchBrowserService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_workspace_1.IWorkspaceService),
    tslib_1.__metadata("design:type", Object)
], SearchTreeService.prototype, "workspaceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(browser_1.IEditorDocumentModelContentRegistry),
    tslib_1.__metadata("design:type", Object)
], SearchTreeService.prototype, "contentRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ReplaceDocumentModelContentProvider),
    tslib_1.__metadata("design:type", ReplaceDocumentModelContentProvider)
], SearchTreeService.prototype, "replaceDocumentModelContentProvider", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(RangeHighlightDecorations),
    tslib_1.__metadata("design:type", RangeHighlightDecorations)
], SearchTreeService.prototype, "rangeHighlightDecorations", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IFileServiceClient),
    tslib_1.__metadata("design:type", Object)
], SearchTreeService.prototype, "fileServiceClient", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(search_contextkey_1.SearchContextKey),
    tslib_1.__metadata("design:type", search_contextkey_1.SearchContextKey)
], SearchTreeService.prototype, "searchContextKey", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.LabelService),
    tslib_1.__metadata("design:type", ide_core_browser_1.LabelService)
], SearchTreeService.prototype, "labelService", void 0);
tslib_1.__decorate([
    ide_core_common_1.memoize,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], SearchTreeService.prototype, "getCurrentUserHome", null);
SearchTreeService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], SearchTreeService);
exports.SearchTreeService = SearchTreeService;
//# sourceMappingURL=search-tree.service.js.map